# -*- coding: utf-8 -8-
"""
Just imports other modules
"""
from .py import Py
from .fastapi import FastApi
